/////////////////////////////////////////////////////////////////////
// Micro Hachune sample for PIC12F675 / Hitech-C PICCLITE v9.60PL1
// Copyright(c)2009 Sumio Morioka (http://www002.upp.so-net.ne.jp/morioka)
//
// NOTE: COIL is assigned to GP5
/////////////////////////////////////////////////////////////////////

#include <htc.h>
static          bank1 unsigned char	IOC		@ 0x96;

#define	int8	signed char
#define	uint8	unsigned char
#define	int16	signed int
#define	uint16	unsigned int
#define	int32	signed long
#define	uint32	unsigned long

__CONFIG(INTIO & UNPROTECT & BOREN & MCLRDIS & PWRTEN & WDTDIS);


//////////////////////////////////////////////////////////////////////////////////////
// INT_TMR1 (100ms ... monitor motor status & S/W status)
//////////////////////////////////////////////////////////////////////////////////////
void init_tmr1(void);
void interrupt intvec_tmr1(void);

#define	TMR1_VAL		0xFFFF - 12500		// 0xFFFF - (100.0ms / 8us interval)

void init_tmr1(void)
{
//	T1CON	= 0x05;		// T1CON: 0000_0101b : prescale == 1:1		1us interval @4MHz
//	T1CON	= 0x15;		// T1CON: 0001_0101b : prescale == 1:2		2us interval @4MHz
//	T1CON	= 0x25;		// T1CON: 0010_0101b : prescale == 1:4		4us interval @4MHz
	T1CON	= 0x35;		// T1CON: 0011_0101b : prescale == 1:8		8us interval @4MHz

	TMR1H	= (TMR1_VAL >> 8);
	TMR1L	= TMR1_VAL & 0xFF;
	PIR1	= 0x00;
}

void interrupt intvec_tmr1(void)
{
	GPIO5 ^= 1;		// COIL

	// restart TMR
	TMR1H	= (TMR1_VAL >> 8);
	TMR1L	= TMR1_VAL & 0xFF;
	PIR1	= 0x00;
}


//////////////////////////////////////////////////////////////////////////////////////
// MAIN
//////////////////////////////////////////////////////////////////////////////////////

void main()
{
	/////////////////////////////////////////////////////////////////////////////////////
	// init HW
	/////////////////////////////////////////////////////////////////////////////////////
	OSCCAL	= _READ_OSCCAL_DATA();
	INTCON	= 0x00;		// DI()

	OPTION	= 0x80;		// bit7:pull up disable
	GPIO	= 0x00;
	CMCON	= 0x07;		// digital I/O (comparator reset)
	ANSEL	= 0x00;		// bit3-0: digital I/O
	ADCON0	= 0x00;		// bit0: a/d off
	VRCON	= 0x00;		// bit7: vr off
	WPU		= 0x00;		// pull up disable
	TRISIO	= 0x08;		// GP3:in, others:out (GP5: COIL)

	IOC		= 0x00;		// int on chg disabled
	PIE1	= 0x01;		// bit6:a/d conv int disable, bit0:TMR1 int enable
	init_tmr1();

	INTCON	= 0xC0;		// EI(): GIE, PEIE

	/////////////////////////////////////////////////////////////////////////////////////
	// Infinite loop
	/////////////////////////////////////////////////////////////////////////////////////
	while (1) {
		continue;
	}
}
